10000 - Resource Collection Not Found

### Navigation

- index
- next |
- previous |
- fantastico 0.5.0-b126 documentation »
- Fantastico features »
- ROA (Resource Oriented Architecture) »
- ROA Technical Summary »

# 10000 - Resource Collection Not Found

Whenever we try a ROA dynamic REST operation (Read / Create / Update / Delete) on a resource and version which are not registered this error is returned. It is always a json compatible response:

    {"error_code": 10000,
     "error_description": "Friendly error description.",
     "error_details": <link to this page>}